@@ -1,22 +1,11 @@
 // Copyright (C) 2018 Sebastian Dröge <sebastian@centricular.com>
 // Copyright (C) 2019-2022 François Laignel <fengalin@free.fr>
 //
-// This library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
-// License as published by the Free Software Foundation; either
-// version 2 of the License, or (at your option) any later version.
+// This Source Code Form is subject to the terms of the Mozilla Public License, v2.0.
+// If a copy of the MPL was not distributed with this file, You can obtain one at
+// <https://mozilla.org/MPL/2.0/>.
 //
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-// Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public
-// License along with this library; if not, write to the
-// Free Software Foundation, Inc., 51 Franklin Street, Suite 500,
-// Boston, MA 02110-1335, USA.
-//
-// SPDX-License-Identifier: LGPL-2.1-or-later
+// SPDX-License-Identifier: MPL-2.0
 
 use futures::channel::mpsc;
 use futures::prelude::*;
@@ -166,7 +155,7 @@ impl AppSrcTask {
 impl AppSrcTask {
     fn flush(&mut self) {
         // Purge the channel
-        while let Ok(Some(_item)) = self.receiver.try_next() {}
+        while let Ok(_item) = self.receiver.try_recv() {}
     }
 
     async fn push_item(&mut self, item: StreamItem) -> Result<gst::FlowSuccess, gst::FlowError> {
@@ -308,16 +297,19 @@ impl AppSrc {
         let do_timestamp = self.settings.lock().unwrap().do_timestamp;
         if do_timestamp {
             let elem = self.obj();
-            if let Some(clock) = elem.clock() {
-                let base_time = elem.base_time();
-                let now = clock.time();
+            match elem.clock() {
+                Some(clock) => {
+                    let base_time = elem.base_time();
+                    let now = clock.time();
 
-                let buffer = buffer.make_mut();
-                buffer.set_dts(now.opt_checked_sub(base_time).ok().flatten());
-                buffer.set_pts(None);
-            } else {
-                gst::error!(CAT, imp = self, "Don't have a clock yet");
-                return false;
+                    let buffer = buffer.make_mut();
+                    buffer.set_dts(now.opt_checked_sub(base_time).ok().flatten());
+                    buffer.set_pts(None);
+                }
+                _ => {
+                    gst::error!(CAT, imp = self, "Don't have a clock yet");
+                    return false;
+                }
             }
         }
 
