@@ -1,7 +1,11 @@
 // Copyright (C) 2018-2020 Sebastian Dröge <sebastian@centricular.com>
 // Copyright (C) 2019-2022 François Laignel <fengalin@free.fr>
 //
-// Take a look at the license at the top of the repository in the LICENSE file.
+// This Source Code Form is subject to the terms of the Mozilla Public License, v2.0.
+// If a copy of the MPL was not distributed with this file, You can obtain one at
+// <https://mozilla.org/MPL/2.0/>.
+//
+// SPDX-License-Identifier: MPL-2.0
 
 use futures::prelude::*;
 
@@ -14,7 +18,7 @@ use std::sync::{Arc, Mutex};
 use std::task::{self, Poll};
 use std::time::Duration;
 
-use super::{scheduler, JoinHandle, SubTaskOutput, TaskId};
+use super::{JoinHandle, SubTaskOutput, TaskId, scheduler};
 use crate::runtime::RUNTIME_CAT;
 
 // We are bound to using `sync` for the `runtime` `Mutex`es. Attempts to use `async` `Mutex`es
@@ -144,11 +148,11 @@ impl Context {
     pub fn acquire(context_name: &str, wait: Duration) -> Result<Self, io::Error> {
         let mut contexts = CONTEXTS.lock().unwrap();
 
-        if let Some(context_weak) = contexts.get(context_name) {
-            if let Some(context) = context_weak.upgrade() {
-                gst::debug!(RUNTIME_CAT, "Joining Context '{}'", context.name());
-                return Ok(context);
-            }
+        if let Some(context_weak) = contexts.get(context_name)
+            && let Some(context) = context_weak.upgrade()
+        {
+            gst::debug!(RUNTIME_CAT, "Joining Context '{}'", context.name());
+            return Ok(context);
         }
 
         let context = Context(scheduler::Throttling::start(context_name, wait));
@@ -218,22 +222,25 @@ impl Context {
         F: FnOnce() -> O + Send + 'a,
         O: Send + 'a,
     {
-        if let Some(cur) = Context::current().as_ref() {
-            if cur == self {
-                panic!(
-                    "Attempt to enter Context {} within itself, this would deadlock",
-                    self.name()
-                );
-            } else {
-                gst::warning!(
-                    RUNTIME_CAT,
-                    "Entering Context {} within {}",
-                    self.name(),
-                    cur.name()
-                );
+        match Context::current().as_ref() {
+            Some(cur) => {
+                if cur == self {
+                    panic!(
+                        "Attempt to enter Context {} within itself, this would deadlock",
+                        self.name()
+                    );
+                } else {
+                    gst::warning!(
+                        RUNTIME_CAT,
+                        "Entering Context {} within {}",
+                        self.name(),
+                        cur.name()
+                    );
+                }
+            }
+            _ => {
+                gst::debug!(RUNTIME_CAT, "Entering Context {}", self.name());
             }
-        } else {
-            gst::debug!(RUNTIME_CAT, "Entering Context {}", self.name());
         }
 
         self.0.enter(f)
@@ -415,16 +422,16 @@ mod tests {
             add_sub_task(0).unwrap();
 
             // Check that it was not executed yet
-            receiver.try_next().unwrap_err();
+            receiver.try_recv().unwrap_err();
 
             // Drain it now and check that it was executed
             let drain_fut = Context::drain_sub_tasks();
             drain_fut.await.unwrap();
-            assert_eq!(receiver.try_next().unwrap(), Some(0));
+            assert_eq!(receiver.try_recv(), Ok(0));
 
             // Add another task and check that it's not executed yet
             add_sub_task(1).unwrap();
-            receiver.try_next().unwrap_err();
+            receiver.try_recv().unwrap_err();
 
             // Return the receiver
             receiver
@@ -433,8 +440,8 @@ mod tests {
         let mut receiver = futures::executor::block_on(join_handle).unwrap();
 
         // The last sub task should be simply dropped at this point
-        match receiver.try_next() {
-            Ok(None) | Err(_) => (),
+        match receiver.try_recv() {
+            Err(_) => (),
             other => panic!("Unexpected {other:?}"),
         }
     }
