@@ -1,22 +1,11 @@
 // Copyright (C) 2019-2022 François Laignel <fengalin@free.fr>
 // Copyright (C) 2020 Sebastian Dröge <sebastian@centricular.com>
 //
-// This library is free software; you can redistribute it and/or
-// modify it under the terms of the GNU Library General Public
-// License as published by the Free Software Foundation; either
-// version 2 of the License, or (at your option) any later version.
+// This Source Code Form is subject to the terms of the Mozilla Public License, v2.0.
+// If a copy of the MPL was not distributed with this file, You can obtain one at
+// <https://mozilla.org/MPL/2.0/>.
 //
-// This library is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-// Library General Public License for more details.
-//
-// You should have received a copy of the GNU Library General Public
-// License along with this library; if not, write to the
-// Free Software Foundation, Inc., 51 Franklin Street, Suite 500,
-// Boston, MA 02110-1335, USA.
-//
-// SPDX-License-Identifier: LGPL-2.1-or-later
+// SPDX-License-Identifier: MPL-2.0
 
 //! An implementation of `Pad`s to run asynchronous processings.
 //!
@@ -79,8 +68,8 @@ use std::marker::PhantomData;
 use std::ops::Deref;
 use std::sync::{Arc, Weak};
 
-use super::executor::{self, Context};
 use super::RUNTIME_CAT;
+use super::executor::{self, Context};
 
 #[inline]
 fn event_ret_to_event_full_res(
@@ -817,17 +806,22 @@ impl PadSink {
                             let elem = imp.obj().clone();
                             let gst_pad = gst_pad.clone();
 
-                            if let Some((ctx, task_id)) = Context::current_task() {
-                                let delayed_fut = async move {
-                                    H::sink_chain(handler, gst_pad, elem, buffer).await
-                                };
-                                let _ =
-                                    ctx.add_sub_task(task_id, delayed_fut.map(|res| res.map(drop)));
+                            match Context::current_task() {
+                                Some((ctx, task_id)) => {
+                                    let delayed_fut = async move {
+                                        H::sink_chain(handler, gst_pad, elem, buffer).await
+                                    };
+                                    let _ = ctx.add_sub_task(
+                                        task_id,
+                                        delayed_fut.map(|res| res.map(drop)),
+                                    );
 
-                                Ok(gst::FlowSuccess::Ok)
-                            } else {
-                                let chain_fut = H::sink_chain(handler, gst_pad, elem, buffer);
-                                executor::block_on(chain_fut)
+                                    Ok(gst::FlowSuccess::Ok)
+                                }
+                                _ => {
+                                    let chain_fut = H::sink_chain(handler, gst_pad, elem, buffer);
+                                    executor::block_on(chain_fut)
+                                }
                             }
                         },
                     )
@@ -845,18 +839,23 @@ impl PadSink {
                             let elem = imp.obj().clone();
                             let gst_pad = gst_pad.clone();
 
-                            if let Some((ctx, task_id)) = Context::current_task() {
-                                let delayed_fut = async move {
-                                    H::sink_chain_list(handler, gst_pad, elem, list).await
-                                };
-                                let _ =
-                                    ctx.add_sub_task(task_id, delayed_fut.map(|res| res.map(drop)));
+                            match Context::current_task() {
+                                Some((ctx, task_id)) => {
+                                    let delayed_fut = async move {
+                                        H::sink_chain_list(handler, gst_pad, elem, list).await
+                                    };
+                                    let _ = ctx.add_sub_task(
+                                        task_id,
+                                        delayed_fut.map(|res| res.map(drop)),
+                                    );
 
-                                Ok(gst::FlowSuccess::Ok)
-                            } else {
-                                let chain_list_fut =
-                                    H::sink_chain_list(handler, gst_pad, elem, list);
-                                executor::block_on(chain_list_fut)
+                                    Ok(gst::FlowSuccess::Ok)
+                                }
+                                _ => {
+                                    let chain_list_fut =
+                                        H::sink_chain_list(handler, gst_pad, elem, list);
+                                    executor::block_on(chain_list_fut)
+                                }
                             }
                         },
                     )
@@ -877,22 +876,27 @@ impl PadSink {
                                 let elem = imp.obj().clone();
                                 let gst_pad = gst_pad.clone();
 
-                                if let Some((ctx, task_id)) = Context::current_task() {
-                                    let delayed_fut = async move {
-                                        H::sink_event_full_serialized(handler, gst_pad, elem, event)
+                                match Context::current_task() {
+                                    Some((ctx, task_id)) => {
+                                        let delayed_fut = async move {
+                                            H::sink_event_full_serialized(
+                                                handler, gst_pad, elem, event,
+                                            )
                                             .await
-                                    };
-                                    let _ = ctx.add_sub_task(
-                                        task_id,
-                                        delayed_fut.map(|res| res.map(drop)),
-                                    );
+                                        };
+                                        let _ = ctx.add_sub_task(
+                                            task_id,
+                                            delayed_fut.map(|res| res.map(drop)),
+                                        );
 
-                                    Ok(gst::FlowSuccess::Ok)
-                                } else {
-                                    let event_fut = H::sink_event_full_serialized(
-                                        handler, gst_pad, elem, event,
-                                    );
-                                    executor::block_on(event_fut)
+                                        Ok(gst::FlowSuccess::Ok)
+                                    }
+                                    _ => {
+                                        let event_fut = H::sink_event_full_serialized(
+                                            handler, gst_pad, elem, event,
+                                        );
+                                        executor::block_on(event_fut)
+                                    }
                                 }
                             } else {
                                 handler.sink_event_full(gst_pad, imp, event)
