@@ -120,7 +120,7 @@ impl OnvifMetadataOverlay {
             let mut query = gst::query::Allocation::new(Some(&caps), false);
 
             if !self.srcpad.push_event(gst::event::Caps::new(&caps)) {
-                return Err(gst::FlowError::NotNegotiated);
+                gst::info!(CAT, imp = self, "Failed to push caps event");
             }
 
             if !self.srcpad.peer_query(&mut query)
@@ -142,10 +142,9 @@ impl OnvifMetadataOverlay {
             self.state.lock().unwrap().attach = false;
 
             if !self.srcpad.push_event(gst::event::Caps::new(&caps)) {
-                Err(gst::FlowError::NotNegotiated)
-            } else {
-                Ok(gst::FlowSuccess::Ok)
+                gst::info!(CAT, imp = self, "Failed to push caps event");
             }
+            Ok(gst::FlowSuccess::Ok)
         }
     }
 
@@ -362,14 +361,14 @@ impl OnvifMetadataOverlay {
     ) -> Result<gst::FlowSuccess, gst::FlowError> {
         gst::trace!(CAT, obj = pad, "Handling buffer {:?}", buffer);
 
-        if self.srcpad.check_reconfigure() {
-            if let Err(err) = self.negotiate() {
-                if self.srcpad.pad_flags().contains(gst::PadFlags::FLUSHING) {
-                    self.srcpad.mark_reconfigure();
-                    return Ok(gst::FlowSuccess::Ok);
-                } else {
-                    return Err(err);
-                }
+        if self.srcpad.check_reconfigure()
+            && let Err(err) = self.negotiate()
+        {
+            if self.srcpad.pad_flags().contains(gst::PadFlags::FLUSHING) {
+                self.srcpad.mark_reconfigure();
+                return Ok(gst::FlowSuccess::Ok);
+            } else {
+                return Err(err);
             }
         }
 
@@ -864,11 +863,13 @@ impl ObjectSubclass for OnvifMetadataOverlay {
 impl ObjectImpl for OnvifMetadataOverlay {
     fn properties() -> &'static [glib::ParamSpec] {
         static PROPERTIES: LazyLock<Vec<glib::ParamSpec>> = LazyLock::new(|| {
-            vec![glib::ParamSpecString::builder("font-desc")
-                .nick("Font Description")
-                .blurb("Pango font description of font to be used for rendering")
-                .default_value(Some(DEFAULT_FONT_DESC))
-                .build()]
+            vec![
+                glib::ParamSpecString::builder("font-desc")
+                    .nick("Font Description")
+                    .blurb("Pango font description of font to be used for rendering")
+                    .default_value(Some(DEFAULT_FONT_DESC))
+                    .build(),
+            ]
         });
 
         PROPERTIES.as_ref()
