@@ -13,13 +13,12 @@
  *
  * Since: plugins-rs-0.15.0
  */
-use crate::st2038anc_utils::{add_ancillary_meta_to_buffer, AncData};
+use crate::st2038anc_utils::{AncData, add_ancillary_meta_to_buffer};
 use gst::glib;
 use gst::prelude::*;
 use gst::subclass::prelude::*;
 use gst_base::prelude::*;
 use gst_base::subclass::prelude::*;
-use gst_video::video_meta::AncillaryMeta;
 use std::sync::{LazyLock, Mutex, MutexGuard};
 
 const FALLBACK_FRAME_DURATION: gst::ClockTime = gst::ClockTime::from_mseconds(50);
@@ -79,7 +78,7 @@ impl ElementImpl for St2038Combiner {
     fn pad_templates() -> &'static [gst::PadTemplate] {
         static PAD_TEMPLATES: LazyLock<Vec<gst::PadTemplate>> = LazyLock::new(|| {
             let sink_caps = gst::Caps::builder("meta/x-st-2038")
-                .field("alignment", "frame")
+                .field("alignment", gst::List::new(["packet", "line", "frame"]))
                 .build();
 
             let st2038_pad_template = gst::PadTemplate::with_gtype(
@@ -118,10 +117,10 @@ impl ElementImpl for St2038Combiner {
     fn release_pad(&self, pad: &gst::Pad) {
         {
             let mut state = self.state.lock().unwrap();
-            if let Some(st2038_pad) = &state.st2038_sinkpad {
-                if st2038_pad == pad.downcast_ref::<gst_base::AggregatorPad>().unwrap() {
-                    state.st2038_sinkpad.take();
-                }
+            if let Some(st2038_pad) = &state.st2038_sinkpad
+                && st2038_pad == pad.downcast_ref::<gst_base::AggregatorPad>().unwrap()
+            {
+                state.st2038_sinkpad.take();
             }
         }
 
@@ -269,10 +268,16 @@ impl AggregatorImpl for St2038Combiner {
                 let running_time_end = video_buffer
                     .duration()
                     .or_else(|| {
-                        state.framerate.as_ref().and_then(|framerate| {
-                            gst::ClockTime::SECOND
-                                .mul_div_round(framerate.denom() as u64, framerate.numer() as u64)
-                        })
+                        state
+                            .framerate
+                            .as_ref()
+                            .filter(|framerate| framerate.numer() != 0)
+                            .and_then(|framerate| {
+                                gst::ClockTime::SECOND.mul_div_round(
+                                    framerate.denom() as u64,
+                                    framerate.numer() as u64,
+                                )
+                            })
                     })
                     .and_then(|duration| {
                         let end_time = video_start_pts + duration;
@@ -499,17 +504,16 @@ impl AggregatorImpl for St2038Combiner {
 }
 
 impl St2038Combiner {
-    fn buffer_to_ancdata(&self, buffer: gst::Buffer) -> Result<Vec<AncData>, gst::FlowError> {
+    fn buffer_to_ancdata(
+        &self,
+        anc_data: &mut Vec<AncData>,
+        buffer: gst::Buffer,
+    ) -> Result<(), gst::FlowError> {
         let Ok(map) = buffer.map_readable() else {
             gst::error!(CAT, imp = self, "Failed to map buffer");
             return Err(gst::FlowError::Error);
         };
 
-        let anc_data_sz = buffer
-            .iter_meta::<AncillaryMeta>()
-            .map(|meta| 70 + meta.data().len() * 10 / 8 + 1)
-            .sum::<usize>();
-        let mut anc_data = Vec::with_capacity(anc_data_sz);
         let mut slice = map.as_slice();
 
         while !slice.is_empty() {
@@ -535,7 +539,7 @@ impl St2038Combiner {
             anc_data.push(anc);
         }
 
-        Ok(anc_data)
+        Ok(())
     }
 
     // Only if we collected all ST-2038 we replace the current video
@@ -629,44 +633,47 @@ impl St2038Combiner {
                     gst::FlowError::Error
                 })?;
 
-            gst::debug!(CAT,
+            gst::debug!(
+                CAT,
                 imp = self,
                 "ST-2038 buffer with PTS: {st2038_time}, current_video_running_time: {:?}, current_video_running_time_end: {:?}, previous_video_running_time_end: {:?}",
-                state.current_video_running_time, state.current_video_running_time_end, state.previous_video_running_time_end);
+                state.current_video_running_time,
+                state.current_video_running_time_end,
+                state.previous_video_running_time_end
+            );
 
             if let Some(current_video_running_time_end) = state.current_video_running_time_end {
                 if st2038_time >= current_video_running_time_end {
                     gst::debug!(
-                                CAT,
-                                imp = self,
-                                "Collected all ST-2038 data for this video buffer, {st2038_time} >= {current_video_running_time_end}"
-                            );
+                        CAT,
+                        imp = self,
+                        "Collected all ST-2038 data for this video buffer, {st2038_time} >= {current_video_running_time_end}"
+                    );
                     break;
                 }
             } else {
                 if let Some(previous_video_running_time_end) = state.previous_video_running_time_end
+                    && st2038_time < previous_video_running_time_end
                 {
-                    if st2038_time < previous_video_running_time_end {
-                        gst::debug!(
-                                    CAT,
-                                    imp = self,
-                                    "ST-2038 buffer before end of last video frame, dropping {st2038_time} < {previous_video_running_time_end}"
-                                );
-                        st2038_sinkpad.drop_buffer();
-                        continue;
-                    }
+                    gst::debug!(
+                        CAT,
+                        imp = self,
+                        "ST-2038 buffer before end of last video frame, dropping {st2038_time} < {previous_video_running_time_end}"
+                    );
+                    st2038_sinkpad.drop_buffer();
+                    continue;
                 }
 
-                if let Some(current_video_running_time) = state.current_video_running_time {
-                    if st2038_time < current_video_running_time {
-                        gst::debug!(
-                                    CAT,
-                                    imp = self,
-                                    "ST-2038 buffer before current video frame, dropping {st2038_time} < {current_video_running_time}"
-                                );
-                        st2038_sinkpad.drop_buffer();
-                        continue;
-                    }
+                if let Some(current_video_running_time) = state.current_video_running_time
+                    && st2038_time < current_video_running_time
+                {
+                    gst::debug!(
+                        CAT,
+                        imp = self,
+                        "ST-2038 buffer before current video frame, dropping {st2038_time} < {current_video_running_time}"
+                    );
+                    st2038_sinkpad.drop_buffer();
+                    continue;
                 }
             }
 
@@ -674,17 +681,20 @@ impl St2038Combiner {
             st2038_sinkpad.drop_buffer();
 
             state.last_st2038_ts = buffer.pts();
-            state
-                .current_frame_st2038
-                .extend(self.buffer_to_ancdata(buffer)?);
-
-            gst::debug!(
-                CAT,
-                imp = self,
-                "Collected {} ST-2038 buffer with PTS: {st2038_time:?} for current_video_running_time_end: {:?}",
-                state.current_frame_st2038.len(),
-                state.current_video_running_time_end
-            );
+            if self
+                .buffer_to_ancdata(&mut state.current_frame_st2038, buffer)
+                .is_err()
+            {
+                gst::warning!(CAT, imp = self, "Dropping invalid ST2038 packets");
+            } else {
+                gst::debug!(
+                    CAT,
+                    imp = self,
+                    "Collected {} ST-2038 buffers with PTS: {st2038_time:?} for current_video_running_time_end: {:?}",
+                    state.current_frame_st2038.len(),
+                    state.current_video_running_time_end
+                );
+            }
         }
 
         gst::log!(
@@ -699,6 +709,26 @@ impl St2038Combiner {
         let mut video_buf = state.current_video_buffer.take().unwrap();
 
         if !state.current_frame_st2038.is_empty() {
+            // Sort by line and then horizontal offset. While this is not strictly required
+            // for the ancillary meta, it keeps the output in a nicer order.
+            state
+                .current_frame_st2038
+                .sort_by_key(|anc| (anc.header.line_number, anc.header.horizontal_offset));
+
+            if CAT.above_threshold(gst::DebugLevel::Trace) {
+                for anc in &state.current_frame_st2038 {
+                    gst::trace!(
+                        CAT,
+                        imp = self,
+                        "Attaching ST-2038 for DID {:02X} SDID {:02X} line {} and horizontal offset {} with {} bytes",
+                        anc.header.did,
+                        anc.header.sdid,
+                        anc.header.line_number,
+                        anc.header.horizontal_offset,
+                        anc.header.data_count
+                    );
+                }
+            }
             add_ancillary_meta_to_buffer(video_buf.make_mut(), &state.current_frame_st2038);
             state.current_frame_st2038.clear();
         } else {
@@ -752,11 +782,7 @@ impl St2038Combiner {
         end_time: gst::ClockTime,
     ) -> Result<gst::ClockTime, gst::FlowError> {
         let time_end = if let Some(stop) = segment.stop() {
-            if end_time > stop {
-                stop
-            } else {
-                end_time
-            }
+            if end_time > stop { stop } else { end_time }
         } else {
             end_time
         };
